<?php
/**
 * @Packge     : Kitar
 * @Version    : 1.0
 * @Author     : Themeholy
 * @Author URI : https://themeforest.net/user/themeholy
 *
 */


// Block direct access
if( ! defined( 'ABSPATH' ) ){
    exit;
}

 // theme option callback
function kitar_opt( $id = null, $url = null ){
    global $kitar_opt;

    if( $id && $url ){

        if( isset( $kitar_opt[$id][$url] ) && $kitar_opt[$id][$url] ){
            return $kitar_opt[$id][$url];
        }
    }else{
        if( isset( $kitar_opt[$id] )  && $kitar_opt[$id] ){ 
            return $kitar_opt[$id];
        }
    }
}


// theme logo
function kitar_theme_logo() {
    // escaping allow html
    $allowhtml = array(
        'a'    => array(
            'href' => array()
        ),
        'span' => array(),
        'i'    => array(
            'class' => array()
        )
    );
    $siteUrl = home_url('/');
    if( has_custom_logo() ) {
        $custom_logo_id = get_theme_mod( 'custom_logo' );
        $siteLogo = '';
        $siteLogo .= '<a class="logo" href="'.esc_url( $siteUrl ).'">';
        $siteLogo .= kitar_img_tag( array(
            "class" => "img-fluid",
            "url"   => esc_url( wp_get_attachment_image_url( $custom_logo_id, 'full') )
        ) );
        $siteLogo .= '</a>';

        return $siteLogo;
    } elseif( !kitar_opt('kitar_text_title') && kitar_opt('kitar_site_logo', 'url' )  ){

        $siteLogo = '<img class="img-fluid" src="'.esc_url( kitar_opt('kitar_site_logo', 'url' ) ).'" alt="'.esc_attr__( 'logo', 'kitar' ).'" />';
        return '<a class="logo" href="'.esc_url( $siteUrl ).'">'.$siteLogo.'</a>';


    }elseif( kitar_opt('kitar_text_title') ){
        return '<h2 class="mb-0"><a class="logo" href="'.esc_url( $siteUrl ).'">'.wp_kses( kitar_opt('kitar_text_title'), $allowhtml ).'</a></h2>';
    }else{
        return '<h2 class="mb-0"><a class="logo" href="'.esc_url( $siteUrl ).'">'.esc_html( get_bloginfo('name') ).'</a></h2>';
    }
}

// custom meta id callback
function kitar_meta( $id = '' ){
    $value = get_post_meta( get_the_ID(), '_kitar_'.$id, true );
    return $value;
}


// Blog Date Permalink
function kitar_blog_date_permalink() {
    $year  = get_the_time('Y');
    $month_link = get_the_time('m');
    $day   = get_the_time('d');
    $link = get_day_link( $year, $month_link, $day);
    return $link;
}

//audio format iframe match
function kitar_iframe_match() {
    $audio_content = kitar_embedded_media( array('audio', 'iframe') );
    $iframe_match = preg_match("/\iframe\b/i",$audio_content, $match);
    return $iframe_match;
}


//Post embedded media
function kitar_embedded_media( $type = array() ){
    $content = do_shortcode( apply_filters( 'the_content', get_the_content() ) );
    $embed   = get_media_embedded_in_content( $content, $type );


    if( in_array( 'audio' , $type) ){
        if( count( $embed ) > 0 ){
            $output = str_replace( '?visual=true', '?visual=false', $embed[0] );
        }else{
           $output = '';
        }

    }else{
        if( count( $embed ) > 0 ){
            $output = $embed[0];
        }else{
           $output = '';
        }
    }
    return $output;
}


// WP post link pages
function kitar_link_pages(){
    wp_link_pages( array(
        'before'      => '<div class="page-links"><span class="page-links-title">' . esc_html__( 'Pages:', 'kitar' ) . '</span>',
        'after'       => '</div>',
        'link_before' => '<span>',
        'link_after'  => '</span>',
        'pagelink'    => '<span class="screen-reader-text">' . esc_html__( 'Page', 'kitar' ) . ' </span>%',
        'separator'   => '<span class="screen-reader-text">, </span>',
    ) );
}


// Data Background image attr
function kitar_data_bg_attr( $imgUrl = '' ){
    return 'data-bg-img="'.esc_url( $imgUrl ).'"';
}

// image alt tag
function kitar_image_alt( $url = '' ){
    if( $url != '' ){
        // attachment id by url
        $attachmentid = attachment_url_to_postid( esc_url( $url ) );
       // attachment alt tag
        $image_alt = get_post_meta( esc_html( $attachmentid ) , '_wp_attachment_image_alt', true );
        if( $image_alt ){
            return $image_alt ;
        }else{
            $filename = pathinfo( esc_url( $url ) );
            $alt = str_replace( '-', ' ', $filename['filename'] );
            return $alt;
        }
    }else{
       return;
    }
}


// Flat Content wysiwyg output with meta key and post id

function kitar_get_textareahtml_output( $content ) {
    global $wp_embed;

    $content = $wp_embed->autoembed( $content );
    $content = $wp_embed->run_shortcode( $content );
    $content = wpautop( $content );
    $content = do_shortcode( $content );

    return $content;
}

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */

function kitar_pingback_header() {
    if ( is_singular() && pings_open() ) {
        echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
    }
}
add_action( 'wp_head', 'kitar_pingback_header' );


// Excerpt More
function kitar_excerpt_more( $more ) {
    return '...';
}

add_filter( 'excerpt_more', 'kitar_excerpt_more' );


// kitar comment template callback
function kitar_comment_callback( $comment, $args, $depth ) {
        $add_below = 'comment';
    ?>
    <li <?php comment_class( array('th-comment-item') ); ?>>
        <div id="comment-<?php comment_ID() ?>" class="th-post-comment">
            <?php
                if( get_avatar( $comment, 100 )  ) :
            ?>
            <!-- Author Image -->
            <div class="comment-avater">
                <?php
                    if ( $args['avatar_size'] != 0 ) {
                        echo get_avatar( $comment, 110 );
                    }
                ?>
            </div>
            <!-- Author Image -->
            <?php endif; ?>
            <!-- Comment Content -->
            <div class="comment-content">
                <div class="">
                    <h3 class="name"><?php echo esc_html( ucwords( get_comment_author() ) ); ?></h3>
                    <span class="commented-on"><?php printf( esc_html__('%1$s %2$s', 'kitar'), get_comment_date(), get_comment_time() ); ?></span>
                </div>
                <p class="text"><?php echo get_comment_text(); ?></p>
                <div class="reply_and_edit">
                    <?php
                        $reply_text = wp_kses_post( '<i class="fas fa-reply"></i> Reply', 'kitar' );

                        $edit_reply_text = wp_kses_post( '<i class="fas fa-pencil-alt"></i> Edit', 'kitar' );

                        comment_reply_link(array_merge( $args, array( 'add_below' => $add_below, 'depth' => 3, 'max_depth' => 5, 'reply_text' => $reply_text ) ) );
                    ?>  
                </div>
                <?php if ( $comment->comment_approved == '0' ) : ?>
                <p class="comment-awaiting-moderation"><?php esc_html_e( 'Your comment is awaiting moderation.', 'kitar' ); ?></p>
                <?php endif; ?>
            </div>
        </div>
        <!-- Comment Content -->
<?php
}

//body class
add_filter( 'body_class', 'kitar_body_class' );
function kitar_body_class( $classes ) {
    if( class_exists('ReduxFramework') ) {
        $kitar_blog_single_sidebar = kitar_opt('kitar_blog_single_sidebar');
        if( ($kitar_blog_single_sidebar != '2' && $kitar_blog_single_sidebar != '3' ) || ! is_active_sidebar('kitar-blog-sidebar') ) {
            $classes[] = 'no-sidebar';
        }
        $new_class = is_page() ? kitar_meta('custom_body_class') : null;

        if ( $new_class ) {
            $classes[] = $new_class;
        }
    } else {
        if( !is_active_sidebar('kitar-blog-sidebar') ) {
            $classes[] = 'no-sidebar';
        }
    }

    return $classes;
}

//Global Footer
function kitar_footer_global_option(){
    // Kitar Widget Enable Disable
    if( class_exists( 'ReduxFramework' ) ){
        $kitar_footer_widget_enable = kitar_opt( 'kitar_footerwidget_enable' );
        $kitar_footer_bottom_active = kitar_opt( 'kitar_disable_footer_bottom' );
    }else{
        $kitar_footer_widget_enable = '';
        $kitar_footer_bottom_active = '1';
    }

    if( $kitar_footer_widget_enable == '1' || $kitar_footer_bottom_active == '1' ){
        $bg = kitar_opt('kitar_footer_background', 'background-image' );
        $footer_bg = $bg ? $bg : '#';

        if( ( is_active_sidebar( 'kitar-footer-1' ) || is_active_sidebar( 'kitar-footer-2' ) || is_active_sidebar( 'kitar-footer-3' ) || is_active_sidebar( 'kitar-footer-4' ) )) {
            $class = 'footer-layout2';
        }else{
            $class = '';
        }
        
        echo '<!---footer-wrapper start-->';
        echo '<footer class="footer-wrapper '.esc_attr($class).' prebuilt-foo" data-bg-src="'.esc_url(  $footer_bg ).'">';
            if( $kitar_footer_widget_enable == '1' ){
                if( ( is_active_sidebar( 'kitar-footer-1' ) || is_active_sidebar( 'kitar-footer-2' ) || is_active_sidebar( 'kitar-footer-3' ) || is_active_sidebar( 'kitar-footer-4' ) )) {
                    echo '<div class="widget-area">';
                        echo '<div class="container">';
                                echo '<div class="row justify-content-between">';
                                    if( is_active_sidebar( 'kitar-footer-1' )){
                                    dynamic_sidebar( 'kitar-footer-1' ); 
                                    }
                                    if( is_active_sidebar( 'kitar-footer-2' )){
                                    dynamic_sidebar( 'kitar-footer-2' ); 
                                    }
                                    if( is_active_sidebar( 'kitar-footer-3' )){
                                    dynamic_sidebar( 'kitar-footer-3' ); 
                                    } 
                                    if( is_active_sidebar( 'kitar-footer-4' )){
                                    dynamic_sidebar( 'kitar-footer-4' ); 
                                    }  
                                echo '</div>';
                        echo '</div>';
                    echo '</div>';
                }
            }

            if( $kitar_footer_bottom_active == '1' ){
                echo '<div class="copyright-wrap">';
                    echo '<div class="container text-center">';
                        echo '<p class="copyright-text">'.wp_kses_post( kitar_opt( 'kitar_copyright_text' ) ).'</p>';
                    echo '</div>';
                echo '</div>';
            }

        echo '</footer>';
        echo '<!---footer-wrapper end-->';
    }
}

// Social link = title / description
function kitar_social_icon(){
    $kitar_social_icon = kitar_opt( 'kitar_social_links' );
    if( ! empty( $kitar_social_icon ) && isset( $kitar_social_icon ) ){
        $social_item = '';
        foreach( $kitar_social_icon as $social_icon ){
            if( !empty($social_icon['title']) ){
                $social_item .= '<a href="'.esc_url( $social_icon['url'] ).'"><i class="'.esc_attr( $social_icon['title'] ).'"></i></a>';
            }
        }
        return $social_item;
    }
}

// global header
function kitar_global_header_option() {

    if( class_exists( 'ReduxFramework' ) ){ 
        echo '<header class="th-header header-layout2 prebuilt">';

            if(kitar_opt('kitar_header_sticky')){
                $sticky = '';
            }else{
                $sticky = '-no';
            }

            if(kitar_opt('kitar_menu_icon')){ 
                $menu_icon = '';
            }else{
                $menu_icon = 'hide-icon';
            } 
 
            // echo kitar_header_offcanvas();
            echo kitar_header_cart_offcanvas();
            echo kitar_mobile_menu();
            echo kitar_search_box();
            // Header topbar
            echo kitar_header_menu_topbar(); 

            echo '<div class="sticky-wrapper'.esc_attr($sticky).'">';
                echo '<div class="menu-area">';
                    echo '<div class="container th-container">';
                        echo '<div class="row align-items-center justify-content-between">';
                            echo '<div class="col-auto">';
                                echo '<div class="header-logo">';
                                    echo kitar_theme_logo();
                                echo '</div>';
                            echo '</div>';
                            echo '<div class="col-auto ms-xl-auto">';
                                echo '<nav class="main-menu d-none d-lg-inline-block '.esc_attr($menu_icon).'">';
                                    wp_nav_menu( array(
                                        "theme_location"    => 'primary-menu',
                                        "container"         => '',
                                        "menu_class"        => ''
                                    ) ); 
                                echo '</nav>';
                            echo '</div>';
                            echo '<div class="col-auto">';
                                echo '<div class="header-button">';
                                    if(!empty(kitar_opt( 'kitar_header_search_switcher' )) ){
                                        echo '<button type="button" class="icon-btn searchBoxToggler d-none d-xl-block"><i class="far fa-search"></i></button>';
                                    }
                                    if(!empty(kitar_opt( 'kitar_header_cart_switcher' )) ){
                                        if( class_exists( 'woocommerce' ) ){
                                            global $woocommerce;
                                            if( ! empty( $woocommerce->cart->cart_contents_count ) ){
                                                $count = $woocommerce->cart->cart_contents_count;
                                            }else{
                                                $count = "0";
                                            }
                                            echo '<button type="button" class="icon-btn sideMenuToggler">';
                                                echo '<span class="badge cart_badge">'.esc_html( $count ).'</span>';
                                                echo '<i class="fa-solid fa-cart-shopping"></i>';
                                            echo '</button>'; 
                                        }
                                    }
                                    if( !empty(kitar_opt( 'kitar_btn_text' ) ) ){
                                        echo '<a href="'.esc_url(kitar_opt( 'kitar_btn_url' )).'" class="th-btn th_btn">'.wp_kses_post(kitar_opt( 'kitar_btn_text' )).'</a>';
                                    }
                                    echo '<button type="button" class="th-menu-toggle d-block d-lg-none"><i class="far fa-bars"></i></button>';
                                echo '</div>';
                            echo '</div>';
                        echo '</div>';
                    echo '</div>';

                echo '</div>';
            echo '</div>';
        echo '</header>';
    }else{
        echo kitar_global_header();
    }
}

if( ! function_exists( 'kitar_header_menu_topbar' ) ){
    function kitar_header_menu_topbar(){
        if( class_exists( 'ReduxFramework' ) ){
            $kitar_header_topbar_switcher  = kitar_opt( 'kitar_header_topbar_switcher' );
            $kitar_show_social_switcher      = kitar_opt( 'kitar_header_social_switcher' );
        }else{
            $kitar_header_topbar_switcher  = '';
            $kitar_show_social_switcher    = '';
        }

        if( $kitar_header_topbar_switcher ){

            $phone     = kitar_opt( 'kitar_topbar_phone' );
            $email     = kitar_opt( 'kitar_topbar_email' );
            $address     = kitar_opt( 'kitar_topbar_address' );
            $phone_icon = !empty(kitar_opt( 'kitar_topbar_phone_icon' )) ? kitar_opt( 'kitar_topbar_phone_icon' ): '';
            $email_icon = !empty(kitar_opt( 'kitar_topbar_email_icon' )) ? kitar_opt( 'kitar_topbar_email_icon' ): '';
            $address_icon = !empty(kitar_opt( 'kitar_topbar_address_icon' )) ? kitar_opt( 'kitar_topbar_address_icon' ): '';

            $replace        = array(' ','-',' - ');
            $replace_phone  = array(' ','-',' - ', '(', ')');
            $with           = array('','','');
    
            $phoneurl       = str_replace( $replace_phone, $with, $phone ); 
            $emailurl       = str_replace( $replace, $with, $email );

            echo '<div class="header-top">';
                echo '<div class="container th-container">';
                    echo '<div class="row justify-content-center justify-content-lg-between align-items-center">';
                        echo '<div class="col-auto d-none d-md-block">';
                            echo '<div class="header-links">';
                                echo '<ul>';
                                    if( !empty( $address ) ){
                                        echo ' <li class="d-none d-xl-inline-block">';
                                            if( !empty( $address_icon ) ){
                                                echo wp_kses_post( $address_icon );
                                            }
                                            echo '<a href="'.esc_url(kitar_opt( 'address_url' )).'">'.esc_html( $address ).'</a>';
                                        echo '</li>';
                                    }
                                    if( !empty( $email ) ){
                                        echo '<li>';
                                            if( !empty( $email_icon ) ){
                                                echo wp_kses_post( $email_icon );
                                            }
                                            echo esc_html(kitar_opt( 'kitar_topbar_phone_label' ));
                                            echo '<a href="'.esc_attr('mailto:' . $emailurl).'">'. esc_html( $email ) .'</a>';
                                        echo '</li>';
                                    }
                                    if( !empty( $phone ) ){
                                        echo '<li>';
                                            if( !empty( $phone_icon ) ){
                                                echo wp_kses_post( $phone_icon );
                                            }
                                            echo esc_html(kitar_opt( 'kitar_topbar_phone_label' ));
                                            echo '<a href="'.esc_attr('tel:' . $phoneurl).'">'.esc_html( $phone ).'</a>';
                                        echo '</li>';
                                    }
                                echo '</ul>';
                            echo '</div>';
                        echo '</div>';
                        if(!empty($kitar_show_social_switcher) ){
                            echo '<div class="col-auto">';
                                echo '<div class="social-links">';
                                    if(!empty(kitar_opt( 'kitar_header_social_text' ))){
                                        echo '<span class="social-title">'.esc_html(kitar_opt( 'kitar_header_social_text' )).'</span>';
                                    }
                                    echo kitar_social_icon();
                                echo '</div>';
                            echo '</div>';
                        }
                    echo '</div>';
                echo '</div>';
            echo '</div> ';

        }
    }
}

// kitar woocommerce breadcrumb
function kitar_woo_breadcrumb( $args ) {
    return array(
        'delimiter'   => '',
        'wrap_before' => '<ul class="breadcumb-menu">',
        'wrap_after'  => '</ul>',
        'before'      => '<li>',
        'after'       => '</li>',
        'home'        => _x( 'Home', 'breadcrumb', 'kitar' ),
    );
}

add_filter( 'woocommerce_breadcrumb_defaults', 'kitar_woo_breadcrumb' );

function kitar_custom_search_form( $class ) {
    echo '<!-- Search Form -->';

    echo '<form role="search" method="get" action="'.esc_url( home_url( '/' ) ).'" class="'.esc_attr( $class ).'">';
        echo '<label class="searchIcon">';
            echo kitar_img_tag( array(
                "url"   => esc_url( get_theme_file_uri( '/assets/img/search-2.svg' ) ),
                "class" => "svg"
            ) );
            echo '<input value="'.esc_html( get_search_query() ).'" name="s" required type="search" placeholder="'.esc_attr__('What are you looking for?', 'kitar').'">';
        echo '</label>';
    echo '</form>';
    echo '<!-- End Search Form -->';
}



//Fire the wp_body_open action.
if ( ! function_exists( 'wp_body_open' ) ) {
    function wp_body_open() {
        do_action( 'wp_body_open' );
    }
}

//Remove Tag-Clouds inline style
add_filter( 'wp_generate_tag_cloud', 'kitar_remove_tagcloud_inline_style',10,1 );
function kitar_remove_tagcloud_inline_style( $input ){
   return preg_replace('/ style=("|\')(.*?)("|\')/','',$input );
}

/* This code filters the Categories archive widget to include the post count inside the link */
add_filter( 'wp_list_categories', 'kitar_cat_count_span' );
function kitar_cat_count_span( $links ) {
    $links = str_replace('</a> (', '</a> <span class="category-number">', $links);
    $links = str_replace(')', '</span>', $links);
    return $links;
}

/* This code filters the Archive widget to include the post count inside the link */
add_filter( 'get_archives_link', 'kitar_archive_count_span' );
function kitar_archive_count_span( $links ) {
    $links = str_replace('</a>&nbsp;(', '</a> <span class="category-number">', $links);
    $links = str_replace(')', '</span>', $links);
    return $links;
}

// Kitar Default Header
if( ! function_exists( 'kitar_global_header' ) ){
    function kitar_global_header(){ ?>

        <!--Mobile menu & Search box-->
        <?php 
        echo kitar_search_box(); 
        echo kitar_mobile_menu();  
        
        ?>

        <!--======== Header ========-->
        <header class="th-header header-layout1 unittest-header">
            <div class="not-sticky-wrapper">
                <div class="sticky-active">
                    <div class="menu-area">
                        <div class="container">
                            <div class="row gx-20 align-items-center justify-content-between">

                                <div class="col-auto">
                                    <div class="header-logo">
                                        <div class="logo-bg"></div>
                                        <?php echo kitar_theme_logo(); ?>
                                    </div>
                                </div>

                                <div class="col-auto">
                                    <?php
                                    if( has_nav_menu( 'primary-menu' ) ) { ?>
                                        <nav class="main-menu d-none d-lg-inline-block">
                                            <?php
                                            wp_nav_menu( array(
                                                "theme_location"    => 'primary-menu',
                                                "container"         => '',
                                                "menu_class"        => ''
                                            ) ); ?>
                                        </nav>
                                    <?php } ?>                                   
                                    </nav>
                                    <button type="button" class="th-menu-toggle d-inline-block d-lg-none"><i class="far fa-bars"></i></button>
                                </div>
                                <div class="col-auto d-none d-xl-block">
                                    <div class="header-button">
                                        <button type="button" class="icon-btn searchBoxToggler"><i class="far fa-search"></i></button>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </header>
    <?php
    }
}

//header search box
if(! function_exists('kitar_search_box')){
    function kitar_search_box(){
        echo '<div class="popup-search-box d-none d-lg-block">';
            echo '<button class="searchClose"><i class="fal fa-times"></i></button>';
            echo '<form role="search" method="get" action="'.esc_url( home_url( '/' ) ).'">';
                echo '<input value="'.esc_html( get_search_query() ).'" name="s" required type="search" placeholder="'.esc_attr__('What are you looking for?', 'kitar').'">';
                echo '<button type="submit"><i class="fal fa-search"></i></button>';
            echo '</form>';
        echo '</div>';
    }
}

//header Offcanvas
if( ! function_exists( 'kitar_header_offcanvas' ) ){
    function kitar_header_offcanvas(){
        echo '<div class="sidemenu-wrapper sidemenu-info">';
            echo '<div class="sidemenu-content">';
                echo '<button class="closeButton sideMenuCls"><i class="far fa-times"></i></button>';
                if(is_active_sidebar('kitar-offcanvas')){
                    dynamic_sidebar( 'kitar-offcanvas' );
                }else{
                    echo '<h4 class="widget_title">No Widget Added </h4>';
                    echo '<p>Please add some widget in Offcanvs Sidebar</p>';
                }
            echo '</div>';
        echo '</div>';
    }
}

//header Cart Offcanvas
if( ! function_exists( 'kitar_header_cart_offcanvas' ) ){
    function kitar_header_cart_offcanvas(){
        echo '<div class="sidemenu-wrapper sidemenu-cart">';
            echo '<div class="sidemenu-content">';
                echo '<button class="closeButton sideMenuCls"><i class="far fa-times"></i></button>';
                echo '<div class="widget woocommerce widget_shopping_cart">';
                    echo '<h3 class="widget_title">'.esc_html__( 'Shopping cart', 'kitar' ).'</h3>';
                    echo '<div class="widget_shopping_cart_content">';
                        if( class_exists( 'woocommerce' ) ){
                            echo woocommerce_mini_cart();
                        }
                    echo '</div>';
                echo '</div>';
            echo '</div>';
        echo '</div>';
    }
}

// mobile logo
function kitar_mobile_logo() {
    $logo_url = kitar_opt('kitar_mobile_logo', 'url' );
    $mobile_menu = '';
    if( !empty($logo_url )){
        $mobile_menu = '<div class="mobile-logo"><a href="'.home_url('/').'"><img src="'.esc_url($logo_url).'" alt="'.esc_attr__( 'logo', 'kitar' ).'"></a></div>';
    }else{
        $mobile_menu .= '<div class="mobile-logo">';
        $mobile_menu .= kitar_theme_logo();
        $mobile_menu .= '</div>';
    }

    return $mobile_menu;
 }

//header Mobile Menu
if( ! function_exists( 'kitar_mobile_menu' ) ){
    function kitar_mobile_menu(){
    ?>
    <div class="th-menu-wrapper">
        <div class="th-menu-area text-center">
            <button class="th-menu-toggle"><i class="fal fa-times"></i></button>
            <?php  if( class_exists('ReduxFramework') ):?>
                <?php 
                    if(!empty(kitar_opt('kitar_menu_menu_show') )){
                        echo kitar_mobile_logo(); 
                    }
                ?>
            <?php else: ?>
                <div class="mobile-logo">
                    <?php echo kitar_theme_logo(); ?>
                </div>
            <?php endif; ?>
            <div class="th-mobile-menu">
                <?php 
                    if( has_nav_menu( 'primary-menu' ) ){
                        wp_nav_menu( array(
                            "theme_location"    => 'primary-menu',
                            "container"         => '',
                            "menu_class"        => ''
                        ) );
                    }
                ?>
            </div>
        </div>
    </div>

<?php
    }
}



// Blog post views function
function kitar_setPostViews( $postID ) {
    $count_key  = 'post_views_count';
    $count      = get_post_meta( $postID, $count_key, true );
    if( $count == '' ){
        $count = 0;
        delete_post_meta( $postID, $count_key );
        add_post_meta( $postID, $count_key, '0' );
    }else{
        $count++;
        update_post_meta( $postID, $count_key, $count );
    }
}

function kitar_getPostViews( $postID ){
    $count_key  = 'post_views_count';
    $count      = get_post_meta( $postID, $count_key, true );
    if( $count == '' ){
        delete_post_meta( $postID, $count_key );
        add_post_meta( $postID, $count_key, '0' );
        return __( '0', 'kitar' );
    }
    return $count;
}


// Add Extra Class On Comment Reply Button
function kitar_custom_comment_reply_link( $content ) {
    $extra_classes = 'reply-btn';
    return preg_replace( '/comment-reply-link/', 'comment-reply-link ' . $extra_classes, $content);
}

add_filter('comment_reply_link', 'kitar_custom_comment_reply_link', 99);

// Add Extra Class On Edit Comment Link
function kitar_custom_edit_comment_link( $content ) {
    $extra_classes = 'reply-btn';
    return preg_replace( '/comment-edit-link/', 'comment-edit-link ' . $extra_classes, $content);
}

add_filter('edit_comment_link', 'kitar_custom_edit_comment_link', 99);


function kitar_post_classes( $classes, $class, $post_id ) {
    if ( get_post_type() === 'post' ) {
        $classes[] = "th-blog blog-single has-post-thumbnail";
    }elseif( get_post_type() === 'product' ){
        // Return Class
    }elseif( get_post_type() === 'page' ){
        $classes[] = "page--item";
    }
    
    return $classes;
}
add_filter( 'post_class', 'kitar_post_classes', 10, 3 );

// Contact form 7
add_filter('wpcf7_autop_or_not', '__return_false');