<?php
use \Elementor\Widget_Base;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use \Elementor\Utils;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Border;
/**
 *
 * Image Widget .
 *
 */
class kitar_Animated_Shape2 extends Widget_Base {

	public function get_name() {
		return 'kitarshapeimage2';
	}
	public function get_title() {
		return __( 'Section Top Bottom Shape', 'kitar' );
	}
	public function get_icon() {
		return 'th-icon';
    }
	public function get_categories() {
		return [ 'kitar' ];
	}

	protected function register_controls() {

		$this->start_controls_section(
			'image_section',
			[
				'label' 	=> __( 'Image', 'kitar' ),
				'tab' 		=> Controls_Manager::TAB_CONTENT,
			]
        );

		kitar_select_field( $this, 'layout_style', 'Layout Style', ['Style One'] );    

		$this->add_control(
			'effect_style',
			[
				'label' 		=> esc_html__( 'Add Styling Attributes', 'kitar' ),
				'type' 			=> \Elementor\Controls_Manager::SELECT,
				'options' 		=> [
					'section_top'  		=> esc_html__( 'All Section Top Shape', 'kitar' ),
					'section_bottom'  	=> esc_html__( 'All Section Bottom Shape', 'kitar' ),
					'section_top2'  	=> esc_html__( 'Counter Top Shape', 'kitar' ),
				],
				'default' => [ 'section_top'],
			]
		);
		$this->add_control(
			'from_top',
			[
				'label' 		=> __( 'Top', 'kitar' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ '%', 'px' ],
				'range' => [
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'default' => [
					'unit' => '%',
				],
			]
		);
		$this->add_control(
			'from_left',
			[
				'label' 		=> __( 'Left', 'kitar' ),
				'type' 			=> Controls_Manager::SLIDER,
				'size_units' => [ '%', 'px' ],
				'range' 		=> [
					'%' 			=> [
						'min' 			=> 0,
						'max' 			=> 100,
					],
				],
				'default' => [
					'unit' => '%',
				],
			]
		);
		$this->add_control(
			'from_right',
			[
				'label' 		=> __( 'Right', 'kitar' ),
				'type' 			=> Controls_Manager::SLIDER,
				'size_units' => [ '%', 'px' ],
				'range' 		=> [
					'%' 			=> [
						'min' 			=> 0,
						'max' 			=> 100,
					],
				],
				'default' => [
					'unit' => '%',
				],
			]
		);
		$this->add_control(
			'from_bottom',
			[
				'label' 		=> __( 'Bottom', 'kitar' ),
				'type' 			=> Controls_Manager::SLIDER,
				'size_units' => [ '%', 'px' ],
				'range' 		=> [
					'%' 			=> [
						'min' 			=> 0,
						'max' 			=> 100,
					],
				],
				'default' => [
					'unit' => '%',
				],
			]
		);
		$this->add_control(
			'responsive_style',
			[
				'label' 		=> esc_html__( 'Responsive Styling', 'kitar' ),
				'type' 			=> \Elementor\Controls_Manager::SELECT2,
				'label_block' 	=> true,
				'multiple' 		=> true,
				'options' 		=> [
					'd-xxl-block'  		=> esc_html__( 'Hide From Extra large Device (xxl)', 'kitar' ),
					'd-xl-block'  		=> esc_html__( 'Hide From large Device (xl)', 'kitar' ),
					'd-lg-block'  		=> esc_html__( 'Hide From Tablet (lg)', 'kitar' ),
					'd-md-block'  		=> esc_html__( 'Hide From Mobile (md)', 'kitar' ),
					'd-sm-block'  		=> esc_html__( 'D Small Device (sm)', 'kitar' ),
					'd-none'  			=> esc_html__( 'Display None', 'kitar' ),
					' '  				=> esc_html__( 'Default', 'kitar' ),
				],
			]
		);
		$this->add_control(
			'image_class', [
				'label' 		=> __( 'Image Wrap Class Name', 'kitar' ),
				'description' 		=> __( 'Need to add image wrapper class name', 'kitar' ),
				'type' 			=> Controls_Manager::TEXTAREA,
				'rows' 			=> 2,
				'label_block' 	=> true,
			]
        );

        $this->end_controls_section();

	}

	protected function render() {

        $settings = $this->get_settings_for_display();

        $this->add_render_attribute('wrapper','class','shape-mockup');
		if(!empty($settings['image_class'])){
			$this->add_render_attribute('wrapper','class', $settings['image_class']);
		}
        // $this->add_render_attribute('wrapper','class', $settings['effect_style']);
        $this->add_render_attribute('wrapper','class', $settings['responsive_style']);

	    if($settings['from_top']['size']){
	        $this->add_render_attribute( 'wrapper', 'data-top', $settings['from_top']['size'] . $settings['from_top']['unit'] );
	    }
		if($settings['from_bottom']['size']){
	        $this->add_render_attribute( 'wrapper', 'data-bottom', $settings['from_bottom']['size'] . $settings['from_bottom']['unit'] );
	    }
	    if($settings['from_right']['size']){
	        $this->add_render_attribute( 'wrapper', 'data-right', $settings['from_right']['size'] . $settings['from_right']['unit'] );
	    }
	    if($settings['from_left']['size']){
	        $this->add_render_attribute( 'wrapper', 'data-left', $settings['from_left']['size'] . $settings['from_left']['unit'] );
	    }

        if( $settings['effect_style'] == 'section_top' ){
            $this->add_render_attribute('wrapper','data-mask-src',  KITAR_ASSETS.'img/shape/shape.png' );
        }
        if( $settings['effect_style'] == 'section_bottom' ){
            $this->add_render_attribute('wrapper','data-mask-src',  KITAR_ASSETS.'img/shape/shape2.png' );
        }
        if( $settings['effect_style'] == 'section_top2' ){
            $this->add_render_attribute('wrapper','data-mask-src',  KITAR_ASSETS.'img/shape/counter_shape.png' );
        }

		if( $settings['layout_style'] == '1' ){
            echo '<div '.$this->get_render_attribute_string('wrapper').'></div>';

		}elseif( $settings['layout_style'] == '2' ){
			
		}

		
	}
}