<?php
use \Elementor\Widget_Base;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use \Elementor\Group_Control_Border;
use \Elementor\Utils;
/**
 *
 * Blog Post Widget .
 *
 */
class kitar_Blog extends Widget_Base {

	public function get_name() {
		return 'kitarblog';
	}
	public function get_title() {
		return __( 'Blog Post', 'kitar' );
	}
	public function get_icon() {
		return 'th-icon';
    }
	public function get_categories() {
		return [ 'kitar' ];
	}

	protected function register_controls() {

		$this->start_controls_section(
			'blog_post_section',
			[
				'label' => __( 'Blog Post', 'kitar' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

        kitar_select_field( $this, 'layout_style', 'Layout Style', [ 'Style One', 'Style Two' ] );

        kitar_general_fields($this, 'arrow_id', 'Arrow ID', 'TEXT', 'blogSlider1', ['4']);

        $this->add_control(
			'blog_post_count',
			[
				'label' 	=> __( 'No of Post to show', 'kitar' ),
                'type' 		=> Controls_Manager::NUMBER,
                'min'       => 1,
                'max'       => count( get_posts( array('post_type' => 'post', 'post_status' => 'publish', 'fields' => 'ids', 'posts_per_page' => '-1') ) ),
                'default'  	=> __( '4', 'kitar' )
			]
        );

        kitar_general_fields( $this, 'title_count', 'Title Length', 'TEXT2', '6');
        kitar_general_fields( $this, 'excerpt_count', 'Excerpt Length', 'TEXT', '14', ['3']);

        $this->add_control(
			'blog_post_order',
			[
				'label' 	=> __( 'Order', 'kitar' ),
                'type' 		=> Controls_Manager::SELECT,
                'options'   => [
                    'ASC'   	=> __('ASC','kitar'),
                    'DESC'   	=> __('DESC','kitar'),
                ],
                'default'  	=> 'DESC'
			]
        );
        $this->add_control(
			'blog_post_order_by',
			[
				'label' 	=> __( 'Order By', 'kitar' ),
                'type' 		=> Controls_Manager::SELECT,
                'options'   => [
                    'ID'    	=> __( 'ID', 'kitar' ),
                    'author'    => __( 'Author', 'kitar' ),
                    'title'    	=> __( 'Title', 'kitar' ),
                    'date'    	=> __( 'Date', 'kitar' ),
                    'rand'    	=> __( 'Random', 'kitar' ),
                ],
                'default'  	=> 'ID'
			]
        );
        $this->add_control(
			'exclude_cats',
			[
				'label' 		=> __( 'Exclude Categories', 'kitar' ),
                'type' 			=> Controls_Manager::SELECT2,
                'multiple' 		=> true,
				'options' 		=> $this->kitar_get_categories(),
			]
        );
        $this->add_control(
			'exclude_tags',
			[
				'label' 		=> __( 'Exclude Tags', 'kitar' ),
                'type' 			=> Controls_Manager::SELECT2,
                'multiple' 		=> true,
				'options' 		=> $this->kitar_get_tags(),
			]
        );
        $this->add_control(
			'exclude_post_id',
			[
				'label'         => __( 'Exclude Post', 'kitar' ),
                'type'          => Controls_Manager::SELECT2,
                'multiple'      => true,
				'options'       => $this->kitar_post_id(),
			]
        );

        kitar_general_fields( $this, 'button_text', 'Read More Text', 'TEXTAREA2', 'Read More' );

        $this->end_controls_section();

		//---------------------------------------
			//Style Section Start
		//--------------------------------------- 

		//-------Title Style-------
		kitar_common3_style_fields( $this, 'title', 'Title', '{{WRAPPER}} .box-title a', ['1', '2'], 'color', '--theme-color2' );

        //-------General Style-------
		 $this->start_controls_section(
			'general_styling',
			[
				'label'     => __( 'Button Styling', 'kitar' ),
				'tab'       => Controls_Manager::TAB_STYLE,
			]
        );

		kitar_color_fields( $this, 'color', 'Color', '--theme-color', '{{WRAPPER}} .th_btn' );       
		kitar_color_fields( $this, 'color2', 'Hover Color', '--title-color', '{{WRAPPER}} .th_btn' );       

		$this->end_controls_section();



    }

    public function kitar_get_categories() {
        $cats = get_terms(array(
            'taxonomy' => 'category',
            'hide_empty' => true,
        ));

        $cat = [];

        foreach( $cats as $singlecat ) {
            $cat[$singlecat->term_id] = __($singlecat->name,'kitar');
        }

        return $cat;
    }

    public function kitar_get_tags() {
        $tags = get_terms(array(
            'taxonomy' => 'post_tag',
            'hide_empty' => true,
        ));

        $tag = [];

        foreach( $tags as $singletag ) {
            $tag[$singletag->term_id] = __($singletag->name,'kitar');
        }

        return $tag;
    }

    // Get Specific Post
    public function kitar_post_id(){
        $args = array(
            'post_type'         => 'post',
            'posts_per_page'    => -1,
        );

        $kitar_post = new WP_Query( $args );

        $postarray = [];

        while( $kitar_post->have_posts() ){
            $kitar_post->the_post();
            $postarray[get_the_Id()] = get_the_title();
        }
        wp_reset_postdata();
        return $postarray;
    }

	protected function render() {

        $settings = $this->get_settings_for_display();
        $exclude_post = $settings['exclude_post_id'];

        if( !empty( $settings['exclude_cats'] ) && empty( $settings['exclude_tags'] ) && empty( $settings['exclude_post_id'] ) ) {
            $args = array(
                'post_type'             => 'post',
                'posts_per_page'        => esc_attr( $settings['blog_post_count'] ),
                'order'                 => esc_attr( $settings['blog_post_order'] ),
                'orderby'               => esc_attr( $settings['blog_post_order_by'] ),
                'ignore_sticky_posts'   => true,
                'category__not_in'      => $settings['exclude_cats']
            );
        } elseif( !empty( $settings['exclude_cats'] ) && !empty( $settings['exclude_tags'] ) && empty( $settings['exclude_post_id'] ) ) {
            $args = array(
                'post_type'             => 'post',
                'posts_per_page'        => esc_attr( $settings['blog_post_count'] ),
                'order'                 => esc_attr( $settings['blog_post_order'] ),
                'orderby'               => esc_attr( $settings['blog_post_order_by'] ),
                'ignore_sticky_posts'   => true,
                'category__not_in'      => $settings['exclude_cats'],
                'tag__not_in'           => $settings['exclude_tags']
            );
        }elseif( !empty( $settings['exclude_cats'] ) && !empty( $settings['exclude_tags'] ) && !empty( $settings['exclude_post_id'] ) ) {
            $args = array(
                'post_type'             => 'post',
                'posts_per_page'        => esc_attr( $settings['blog_post_count'] ),
                'order'                 => esc_attr( $settings['blog_post_order'] ),
                'orderby'               => esc_attr( $settings['blog_post_order_by'] ),
                'ignore_sticky_posts'   => true,
                'category__not_in'      => $settings['exclude_cats'],
                'tag__not_in'           => $settings['exclude_tags'],
                'post__not_in'          => $exclude_post
            );
        } elseif( !empty( $settings['exclude_cats'] ) && empty( $settings['exclude_tags'] ) && !empty( $settings['exclude_post_id'] ) ) {
            $args = array(
                'post_type'             => 'post',
                'posts_per_page'        => esc_attr( $settings['blog_post_count'] ),
                'order'                 => esc_attr( $settings['blog_post_order'] ),
                'orderby'               => esc_attr( $settings['blog_post_order_by'] ),
                'ignore_sticky_posts'   => true,
                'category__not_in'      => $settings['exclude_cats'],
                'post__not_in'          => $exclude_post
            );
        } elseif( empty( $settings['exclude_cats'] ) && !empty( $settings['exclude_tags'] ) && !empty( $settings['exclude_post_id'] ) ) {
            $args = array(
                'post_type'             => 'post',
                'posts_per_page'        => esc_attr( $settings['blog_post_count'] ),
                'order'                 => esc_attr( $settings['blog_post_order'] ),
                'orderby'               => esc_attr( $settings['blog_post_order_by'] ),
                'ignore_sticky_posts'   => true,
                'tag__not_in'           => $settings['exclude_tags'],
                'post__not_in'          => $exclude_post
            );
        } elseif( empty( $settings['exclude_cats'] ) && !empty( $settings['exclude_tags'] ) && empty( $settings['exclude_post_id'] ) ) {
            $args = array(
                'post_type'             => 'post',
                'posts_per_page'        => esc_attr( $settings['blog_post_count'] ),
                'order'                 => esc_attr( $settings['blog_post_order'] ),
                'orderby'               => esc_attr( $settings['blog_post_order_by'] ),
                'ignore_sticky_posts'   => true,
                'tag__not_in'           => $settings['exclude_tags'],
            );
        } elseif( empty( $settings['exclude_cats'] ) && empty( $settings['exclude_tags'] ) && !empty( $settings['exclude_post_id'] ) ) {
            $args = array(
                'post_type'             => 'post',
                'posts_per_page'        => esc_attr( $settings['blog_post_count'] ),
                'order'                 => esc_attr( $settings['blog_post_order'] ),
                'orderby'               => esc_attr( $settings['blog_post_order_by'] ),
                'ignore_sticky_posts'   => true,
                'post__not_in'          => $exclude_post
            );
        } else {
            $args = array(
                'post_type'             => 'post',
                'posts_per_page'        => esc_attr( $settings['blog_post_count'] ),
                'order'                 => esc_attr( $settings['blog_post_order'] ),
                'orderby'               => esc_attr( $settings['blog_post_order_by'] ),
                'ignore_sticky_posts'   => true
            );
        }

    $blogpost = new WP_Query( $args );

		if( $settings['layout_style'] == '1' ){
            echo '<div class="slider-area">';
                echo '<div class="swiper th-slider has-shadow" id="blogSlider1" data-slider-options=\'{"breakpoints":{"0":{"slidesPerView":1},"576":{"slidesPerView":"1"},"768":{"slidesPerView":"2"},"992":{"slidesPerView":"2"},"1200":{"slidesPerView":"3"}}}\'>';
                    echo '<div class="swiper-wrapper">';
                    while( $blogpost->have_posts() ){
                        $blogpost->the_post(); 
                        $categories = get_the_category();
                        echo '<div class="swiper-slide">';
                            echo '<div class="blog-box" data-mask-src="'.KITAR_ASSETS.'img/blog-shape.png">';
                                echo '<div class="blog-img" data-mask-src="'.KITAR_ASSETS.'img/blog-img-shape.png">';
                                    the_post_thumbnail( 'kitar_334X284' ); 
                                echo '</div>';
                                echo '<div class="blog-box_content">';
                                    echo '<a href="'.esc_url( kitar_blog_date_permalink() ).'" class="blog-date"> '.esc_html( get_the_date('d') ).' <span class="month">'.esc_html( get_the_date('F') ).'</span> </a>';
                                    echo '<h3 class="box-title"><a href="'.esc_url( get_permalink() ).'">'.esc_html( wp_trim_words( get_the_title( ), $settings['title_count'], '' ) ).'</a></h3>';
                                    if(!empty($settings['button_text'])){
                                        echo '<a href="'.esc_url( get_permalink() ).'" class="line-btn th_btn">'.wp_kses_post($settings['button_text']).'</a>';
                                    }
                                echo '</div>';
                            echo '</div>';
                        echo '</div>';
                    }
                    echo '</div>';
                echo '</div>';
                echo '<button data-slider-prev="#blogSlider1" class="slider-arrow slider-prev"><i class="far fa-arrow-left"></i></button>';
                echo '<button data-slider-next="#blogSlider1" class="slider-arrow slider-next"><i class="far fa-arrow-right"></i></button>';
            echo '</div>';

		}elseif( $settings['layout_style'] == '2' ){
            echo '<div class="slider-area">';
                echo '<div class="swiper th-slider has-shadow" id="blogSlider1" data-slider-options=\'{"breakpoints":{"0":{"slidesPerView":1},"576":{"slidesPerView":"1"},"768":{"slidesPerView":"2"},"992":{"slidesPerView":"2"},"1200":{"slidesPerView":"3"}}}\'>';
                    echo '<div class="swiper-wrapper">';
                    while( $blogpost->have_posts() ){
                        $blogpost->the_post(); 
                        $categories = get_the_category();
                        echo '<div class="swiper-slide">';
                            echo '<div class="blog-box style2" data-mask-src="'.KITAR_ASSETS.'img/blog-shape2.png">';
                                echo '<div class="blog-img" data-mask-src="'.KITAR_ASSETS.'img/blog-img-shape.png">';
                                    the_post_thumbnail( 'kitar_334X284' ); 
                                echo '</div>';
                                echo '<div class="blog-box_content">';
                                    echo '<a href="'.esc_url( kitar_blog_date_permalink() ).'" class="blog-date"> '.esc_html( get_the_date('d') ).' <span class="month">'.esc_html( get_the_date('F') ).'</span> </a>';
                                    echo '<h3 class="box-title"><a href="'.esc_url( get_permalink() ).'">'.esc_html( wp_trim_words( get_the_title( ), $settings['title_count'], '' ) ).'</a></h3>';
                                    if(!empty($settings['button_text'])){
                                        echo '<a href="'.esc_url( get_permalink() ).'" class="line-btn th_btn">'.wp_kses_post($settings['button_text']).'</a>';
                                    }
                                echo '</div>';
                            echo '</div>';
                        echo '</div>';
                    }
                    echo '</div>';
                echo '</div>';
                echo '<button data-slider-prev="#blogSlider1" class="slider-arrow slider-prev"><i class="far fa-arrow-left"></i></button>';
                echo '<button data-slider-next="#blogSlider1" class="slider-arrow slider-next"><i class="far fa-arrow-right"></i></button>';
            echo '</div>';

        }elseif( $settings['layout_style'] == '3' ){
          
        }
	
      
	}
}