<?php
use \Elementor\Widget_Base;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use \Elementor\Utils;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Border;
use \Elementor\Repeater;
/**
 *
 * Contact Form Widget .
 *
 */
class kitar_Contact_Form extends Widget_Base {

	public function get_name() {
		return 'kitarcontactform';
	}
	public function get_title() {
		return __( 'Contact Form', 'kitar' );
	}
	public function get_icon() {
		return 'th-icon';
    }
	public function get_categories() {
		return [ 'kitar' ];
	}

	public function get_as_contact_form(){
        if ( ! class_exists( 'WPCF7' ) ) {
            return;
        }
        $as_cfa         = array();
        $as_cf_args     = array( 'posts_per_page' => -1, 'post_type'=> 'wpcf7_contact_form' );
        $as_forms       = get_posts( $as_cf_args );
        $as_cfa         = ['0' => esc_html__( 'Select Form', 'kitar' ) ];
        if( $as_forms ){
            foreach ( $as_forms as $as_form ){
                $as_cfa[$as_form->ID] = $as_form->post_title;
            }
        }else{
            $as_cfa[ esc_html__( 'No contact form found', 'kitar' ) ] = 0;
        }
        return $as_cfa;
    }

	protected function register_controls() {

		$this->start_controls_section(
			'contact_form_section',
			[
				'label' 	=> __( 'Contact Form', 'kitar' ),
				'tab' 		=> Controls_Manager::TAB_CONTENT,
			]
        );

		kitar_select_field( $this, 'layout_style', 'Layout Style', [ 'Style One', 'Style Two', 'Style Three' ] ); 

		kitar_general_fields( $this, 'subtitle', 'Subtitle', 'TEXTAREA2', 'Get Consultation', ['1'] );
		kitar_general_fields( $this, 'title', 'Title', 'TEXTAREA2', 'Get A Free Consultation Contact Us', ['1', '2', '3'] );

		kitar_media_fields( $this, 'image', 'Choose Image', ['1'] );
		kitar_media_fields( $this, 'shape', 'Shape Image', ['1'] );
		kitar_media_fields( $this, 'shape2', 'Shape Image', ['1'] );

		$this->add_control(
            'kitar_select_contact_form',
            [
                'label'   => esc_html__( 'Select Form', 'kitar' ),
                'type'    => Controls_Manager::SELECT,
                'default' => '0',
                'options' => $this->get_as_contact_form(),
            ]
        );

        $this->end_controls_section();

        //---------------------------------------
			//Style Section Start
		//---------------------------------------

		//-------Subtitle Style-------
		kitar_common_style_fields( $this, 'subtitle', 'Subtitle', '{{WRAPPER}} .sub', ['1'] );
		//-------Title Style------- 
		kitar_common_style_fields( $this, 'title', 'Title', '{{WRAPPER}} .title', ['1', '2'] );
		//------Button Style-------
		kitar_button_style_fields( $this, '10', 'Button Styling', '{{WRAPPER}} .th-btn' );

	}

	protected function render() {

	    $settings = $this->get_settings_for_display();

		if( $settings['layout_style'] == '1' ){
			echo '<div class="contact-area bg-title overflow-hidden" data-mask-src="'.KITAR_ASSETS.'img/contact_bg_1.png">';
				echo '<div class="container">';
					echo '<div class="row justify-content-xl-end align-items-center">';
						echo '<div class="col-xl-6">';
							echo '<div class="ps-xl-5 ms-xl-2">';
								echo '<div class="title-area mb-40">';
									if($settings['subtitle']){
										echo '<span class="sub-title sub">'.wp_kses_post($settings['subtitle']).'</span>';
									}
									if($settings['title']){
										echo '<h2 class="sec-title title">'.wp_kses_post($settings['title']).'</h2>';
									}
								echo '</div>';
								echo '<div class="contact-form ajax-contact">';
									if( !empty($settings['kitar_select_contact_form']) ){
										echo do_shortcode( '[contact-form-7  id="'.$settings['kitar_select_contact_form'].'"]' ); 
									}else{
										echo '<div class="alert alert-warning"><p class="m-0">' . __('Please Select contact form.', 'kitar' ). '</p></div>';
									}
								echo '</div>';
							echo '</div>';
						echo '</div>';
					echo '</div>';
				echo '</div>';
				if(!empty($settings['image']['url'])){
					echo '<div class="shape-mockup contact-shape d-none d-xl-block" data-bottom="0%" data-left="0%">';
						echo kitar_img_tag( array(
							'url'	=> esc_url( $settings['image']['url'] ),
						) );
					echo '</div>';
				}
				if(!empty($settings['shape']['url'])){
					echo '<div class="shape-mockup spin d-none d-xl-block" data-top="24%" data-right="2%">';
						echo kitar_img_tag( array(
							'url'	=> esc_url( $settings['shape']['url'] ),
						) );
					echo '</div>';
				}
				if(!empty($settings['shape2']['url'])){
					echo '<div class="shape-mockup jump  d-none d-xl-block" data-bottom="8%" data-right="0%">';
						echo kitar_img_tag( array(
							'url'	=> esc_url( $settings['shape2']['url'] ),
						) );
					echo '</div>';
				}
			echo '</div>';

		}elseif( $settings['layout_style'] == '2' ){
			echo '<div>';
				echo '<div class="contact-form style2 ajax-contact">';
					if($settings['title']){
						echo '<div class="title-area mb-30">';
							echo '<h2 class="sec-title mt-n3 title">'.wp_kses_post($settings['title']).'</h2>';
						echo '</div>';
					}
					if( !empty($settings['kitar_select_contact_form']) ){
						echo do_shortcode( '[contact-form-7  id="'.$settings['kitar_select_contact_form'].'"]' ); 
					}else{
						echo '<div class="alert alert-warning"><p class="m-0">' . __('Please Select contact form.', 'kitar' ). '</p></div>';
					}
				echo '</div>';
			echo '</div>';
			
		}elseif( $settings['layout_style'] == '3' ){
			echo '<div class="th-comment-form">';
				echo '<div class="row">';
					if($settings['title']){
						echo '<h3 class="blog-inner-title h4 mb-2 title">'.wp_kses_post($settings['title']).'</h3>';
					}
					if( !empty($settings['kitar_select_contact_form']) ){
						echo do_shortcode( '[contact-form-7  id="'.$settings['kitar_select_contact_form'].'"]' ); 
					}else{
						echo '<div class="alert alert-warning"><p class="m-0">' . __('Please Select contact form.', 'kitar' ). '</p></div>';
					}
				echo '</div>';
			echo '</div>';

		}
		

	}

}