<?php
use \Elementor\Widget_Base;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use \Elementor\Utils;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Border;
use \Elementor\Repeater;
/**
 *
 * features Widget .
 *
 */
class Kitar_Features extends Widget_Base {

	public function get_name() {
		return 'kitarfeatures';
	}
	public function get_title() {
		return __( 'Features', 'kitar' );
	}
	public function get_icon() {
		return 'th-icon';
    }
	public function get_categories() {
		return [ 'kitar' ];
	}

	protected function register_controls() {

		$this->start_controls_section(
			'arrow_section',
			[
				'label'     => __( 'Features', 'kitar' ),
				'tab'       => Controls_Manager::TAB_CONTENT,
			]
        );

		kitar_select_field( $this, 'layout_style', 'Layout Style', [ 'Style One', 'Style Two' ] );

		$repeater = new Repeater();

		kitar_media_fields($repeater, 'icon', 'Choose Icon');
		kitar_general_fields($repeater, 'title', 'Title', 'TEXTAREA2', 'Licensed Child Care');
		kitar_general_fields($repeater, 'desc', 'Description', 'TEXTAREA', ''); 
		$repeater->add_control(
			'color',
			[
				'label' => esc_html__( 'Color 1', 'kitar' ),
				'type' => \Elementor\Controls_Manager::COLOR,
			]
		);
		$repeater->add_control(
			'color2',
			[
				'label' => esc_html__( 'Color 2', 'kitar' ),
				'type' => \Elementor\Controls_Manager::COLOR,
			]
		);
		
		$this->add_control(
			'features',
			[
				'label' 		=> __( 'Featrues', 'kitar' ),
				'type' 			=> Controls_Manager::REPEATER,
				'fields' 		=> $repeater->get_controls(),
				'default' 		=> [
					[
						'title' 	=> __( 'Licensed Child Care', 'kitar' ),
					],
				],
				'condition'	=> [
					'layout_style' => ['1']
				]
			]
		);

		kitar_common_repeater_field($this, 'features2', 'Features', [ 'icon', 'title', 'text'  ], ['2']);

		kitar_media_fields( $this, 'image', 'Choose Image', [ '2']  );
		kitar_media_fields( $this, 'shape', 'Choose Shape', [ '2'] );


        $this->end_controls_section();

        //---------------------------------------
			//Style Section Start
		//---------------------------------------

		//-------Title Style-------
		kitar_common_style_fields( $this, 'title', 'Title', '{{WRAPPER}} .title', [ '1', '2' ] );
		//-------Description Style-------
		kitar_common_style_fields( $this, 'desc', 'Description', '{{WRAPPER}} .desc', [ '1', '2' ] );

	}

	protected function render() {

    $settings = $this->get_settings_for_display(); 

		if( $settings['layout_style'] == '1' ){
			echo '<div class="row gy-4 justify-content-center">';
				foreach( $settings['features'] as $data ){
					echo '<div class="col-md-6 col-xl-3">';
						echo '<div class="feature-item th-ani" data-bg-color="'.esc_attr($data['color']).'">';
							echo '<div class="feature-shape" data-theme-color="'.esc_attr($data['color2']).'"></div>';
							if(!empty($data['icon']['url'])){
								echo '<div class="feature-item_icon">';
									echo kitar_img_tag( array(
										'url'   => esc_url( $data['icon']['url'] ),
									));
								echo '</div>';
							}
							echo '<div class="media-body">';
								if(!empty($data['title'])){
									echo '<h3 class="box-title title">'.wp_kses_post($data['title']).'</h3>';
								}
								if(!empty($data['desc'])){
									echo '<p class="feature-item_text desc">'.wp_kses_post($data['desc']).'</p>';
								}
							echo '</div>';
						echo '</div>';
					echo '</div>';
				}
			echo '</div>';

		}elseif( $settings['layout_style'] == '2' ){
			echo '<div class="row gy-4 justify-content-between align-items-center">';
				echo '<div class="col-md-6 col-xl-auto">';
					foreach( $settings['features2'] as $index => $data ){
						if ($index % 2 == 0) {
							echo '<div class="about-block">';
								if(!empty($data['features_icon']['url'])){
									echo '<div class="about-block_icon">';
										echo kitar_img_tag( array(
											'url'   => esc_url( $data['features_icon']['url'] ),
										));
									echo '</div>';
								}
								echo '<div class="about-block_wrapper">';
									if(!empty($data['features_title'])){
										echo '<h3 class="box-title title">'.wp_kses_post($data['features_title']).'</h3>';
									}
									if(!empty($data['features_text'])){
										echo '<p class="mb-n2 desc">'.wp_kses_post($data['features_text']).'</p>';
									}
								echo '</div>';
							echo '</div>';
						}
					}
				echo '</div>';
				if(!empty($settings['image']['url'])){
				echo '<div class="col col-xl-auto text-center d-none d-xl-block">';
					echo '<div class="about-image wow fadeInUp shape-mockup-wrap">';
						echo kitar_img_tag( array(
							'url'   => esc_url( $settings['image']['url'] ),
						));
						if(!empty( esc_url( $settings['shape']['url'] ))){
						echo '<div class="shape-mockup  movingX d-none d-xxl-block" data-top="45%" data-right="-1%">';
							echo kitar_img_tag( array(
								'url'   => esc_url( $settings['shape']['url'] ),
							));
						echo '</div>';
						}
					echo '</div>';
				echo '</div>';
				}
				echo '<div class="col-md-6 col-xl-auto">';
					foreach( $settings['features2'] as $index => $data ){
						if ($index % 2 == 1) {
							echo '<div class="about-block style1">';
								if(!empty($data['features_icon']['url'])){
									echo '<div class="about-block_icon">';
										echo kitar_img_tag( array(
											'url'   => esc_url( $data['features_icon']['url'] ),
										));
									echo '</div>';
								}
								echo '<div class="about-block_wrapper">';
									if(!empty($data['features_title'])){
										echo '<h3 class="box-title title">'.wp_kses_post($data['features_title']).'</h3>';
									}
									if(!empty($data['features_text'])){
										echo '<p class="mb-n2 desc">'.wp_kses_post($data['features_text']).'</p>';
									}
								echo '</div>';
							echo '</div>';
						}
					}
				echo '</div>';
			echo '</div>';
			

		}elseif( $settings['layout_style'] == '3' ){
			

		}
		
			
	}
}