<?php
use \Elementor\Widget_Base;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use \Elementor\Utils;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Border;
use \Elementor\Repeater;
/**
 *
 * Filter Widgets .
 *
 */
class Kitar_Filter_Widgets extends Widget_Base {

	public function get_name() {
		return 'kitarfilterwidgets';
	}
	public function get_title() {
		return __( 'Filter Widgets', 'kitar' );
	}
	public function get_icon() {
		return 'th-icon';
    }
	public function get_categories() {
		return [ 'kitar' ];
	}

	protected function register_controls() {

		 $this->start_controls_section(
			'service_section',
			[
				'label'     => __( 'Filter Widgets 2 ', 'kitar' ),
				'tab'       => Controls_Manager::TAB_CONTENT,
			]
        );

		kitar_select_field( $this, 'layout_style', 'Layout Style',['Style One'] );

		$this->add_control(
			'show_load_more',
			[
				'label' 		=> __( 'Show Load More Option?', 'kitar' ),
				'type' 			=> Controls_Manager::SWITCHER,
				'label_on' 		=> __( 'Show', 'kitar' ),
				'label_off' 	=> __( 'Hide', 'kitar' ),
				'return_value' 	=> 'yes',
				'default' 		=> 'yes',
			]
		);
		$this->add_control(
			'filter_item_count',
			[
				'label' 	=> __( 'No of Item to show', 'kitar' ),
                'type' 		=> Controls_Manager::NUMBER,
                'min'       => 1,
                'max'       => 16,
                'default'  	=> __( '8', 'kitar' ),
				'condition'	=> [
					'show_load_more' => [ 'yes' ],
				]
			]
        );
		$this->add_control(
			'filter_loop_item_count',
			[
				'label' 	=> __( 'No of Item Loop to show', 'kitar' ),
                'type' 		=> Controls_Manager::NUMBER,
                'min'       => 1,
                'max'       => 16,
                'default'  	=> __( '3', 'kitar' ),
				'condition'	=> [
					// 'layout_style' => ['3'],
					'show_load_more' => [ 'yes' ],
				]
			]
        );

		$this->add_control(
			'show_all',
			[
				'label' 		=> __( 'Show All Tab?', 'kitar' ),
				'type' 			=> Controls_Manager::SWITCHER,
				'label_on' 		=> __( 'Show', 'kitar' ),
				'label_off' 	=> __( 'Hide', 'kitar' ),
				'return_value' 	=> 'yes',
				'default' 		=> 'yes',
			]
		);
		$this->add_control(
			'all_title',
			[
				'label' 	=> __( 'All Tab Text', 'kitar' ),
                'type' 		=> Controls_Manager::TEXT,
                'default'  	=> __( 'Show All Work', 'kitar' ),
				'condition'	=> [
					'show_all' => [ 'yes' ],
				]
			]
        );

		$repeater = new Repeater();

		kitar_general_fields($repeater, 'tab_title', 'Tab Title', 'TEXT', 'Building Construction');
		kitar_general_fields($repeater, 'tab_id', 'Filter Tab ID', 'TEXT', 'cat1');

		$this->add_control(
			'filter_tab',
			[
				'label' 		=> __( 'Filter Tab', 'kitar' ),
				'type' 			=> Controls_Manager::REPEATER,
				'fields' 		=> $repeater->get_controls(),
				'default' 		=> [
					[
						'tab_title' 		=> __( 'Building Construction', 'kitar' ),
					],
				],
			]
		);

		$repeater = new Repeater();

		kitar_general_fields($repeater, 'tab_id2', 'Filter Content ID', 'TEXT', 'cat1');
		kitar_media_fields($repeater, 'choose_image', 'Choose Image');
		kitar_general_fields($repeater, 'subtitle', 'Subtitle', 'TEXT', 'Residential');
		kitar_general_fields($repeater, 'title', 'Title', 'TEXTAREA', 'Pool Water Cleaning');
		kitar_url_fields($repeater, 'url', 'Button URL');

		$this->add_control(
			'filter_list',
			[
				'label' 		=> __( 'Filter Lists', 'kitar' ),
				'type' 			=> Controls_Manager::REPEATER,
				'fields' 		=> $repeater->get_controls(),
				'default' 		=> [
					[
						'title' 		=> __( 'Building Construction', 'kitar' ),
					],
				],
			]
		);

        $this->end_controls_section();

        //---------------------------------------
			//Style Section Start
		//---------------------------------------

		//-------Title Style-------
		kitar_common2_style_fields( $this, 'title', 'Title', '{{WRAPPER}} .title a' );
		//-------Description Style-------
		kitar_common_style_fields( $this, 'desc', 'Description', '{{WRAPPER}} .desc' );

	}

	protected function render() {

        $settings = $this->get_settings_for_display();

		if( $settings['layout_style'] == '1' ){
			$filter_item_count = $settings['filter_item_count'];
			$filter_loop_item_count = $settings['filter_loop_item_count'];

			if(!empty($settings['show_load_more'])){
				$hidden = 'hidden';
			}else{
				$hidden = '';
			}

			echo '<div class="filter-menu style2 indicator-active filter-menu-active">';
				if(!empty($settings['show_all'])){
					$active = '';
					if(!empty($settings['all_title'])){
						$title = $settings['all_title'];
					}else{
						$title = 'Show All Work';
					}
					echo '<button data-filter="*" class="tab-btn active" type="button">'.esc_html($title).'</button>';
				}else{
					$active = 'active';
				}
				foreach( $settings['filter_tab'] as $key => $data ){
					$id = strtolower($data['tab_id']);
					$active_class = ($key == 0) ? $active : '';
				echo '<button data-filter=".'.esc_attr($id).'" class="tab-btn '.esc_attr($active_class).'" type="button">'.esc_html($data['tab_title']).'</button>';
				}
			echo '</div>';

			echo '<div class="row gallery-row th-filter-active">';
				$x=0;
				foreach( $settings['filter_list'] as $data ){
					$x++;
					$id = strtolower($data['tab_id2']);
					echo '<div class="col-md-6 col-xl-auto '.esc_attr($hidden).' filter-item '.esc_attr($id).'">';
						echo '<div class="project-box">';
							if(!empty($data['choose_image']['url'])){
								echo '<div class="project-box-img">';
									echo kitar_img_tag( array(
										'url'   => esc_url( $data['choose_image']['url'] ),
									));
								echo '</div>';
							}
							echo '<div class="project-box-content">';
								if(!empty($data['subtitle'])){
									echo '<p class="project-subtitle desc">'.esc_html($data['subtitle']).'</p>';
								}
								if(!empty($data['title'])){
									echo '<h3 class="box-title title"><a href="'.esc_url( $data['url']['url'] ).'">'.esc_html($data['title']).'</a></h3>';
								}
								echo '<a href="'.esc_url( $data['choose_image']['url'] ).'" class="gallery-btn popup-image"><i class="fa-regular fa-plus"></i></a>';
							echo '</div>';
						echo '</div>';
					echo '</div>';
				}
			echo '</div>';
			if(!empty($settings['show_load_more'])){
				if($x > $filter_item_count){
					echo '<div class="mt-5 pt-3 d-flex justify-content-center">';
						echo '<button id="load-more-btn" class="th-btn">Load More</button>';
					echo '</div>';
				}
			}
		?>

<script>
	jQuery(document).ready(function($) {

		$(".th-filter-active").imagesLoaded(function () {
			var $filter = ".th-filter-active",
				$filterItem = ".filter-item",
				$filterMenu = ".filter-menu-active";

			if ($($filter).length > 0) {
				var $grid = $($filter).isotope({ 
					itemSelector: $filterItem,
					filter: "*",
					masonry: {
						// use outer width of grid-sizer for columnWidth
						columnWidth: 1,
					},
				});

				// filter items on button click
				$($filterMenu).on("click", "button", function () {
					var filterValue = $(this).attr("data-filter");
					$grid.isotope({
						filter: filterValue,
					});
				});

				// Menu Active Class
				$($filterMenu).on("click", "button", function (event) {
					event.preventDefault();
					$(this).addClass("active");
					$(this).siblings(".active").removeClass("active");
				});
			}

			<?php if(!empty($settings['show_load_more'])){ ?>
				var initShow = <?php echo $filter_item_count; ?>;
				var counter = <?php echo $filter_loop_item_count; ?>;
				var iso = $grid.data('isotope');

				loadMore(initShow);

				function loadMore(toShow) {
					$grid.find(".hidden").removeClass("hidden");

					var hiddenElems = iso.filteredItems.slice(toShow, iso.filteredItems.length).map(function(item) {
					return item.element;
					});
					$(hiddenElems).addClass('hidden');
					$grid.isotope('layout');

					//when no more to load, hide show more button
					if (hiddenElems.length == 0) {
						jQuery("#load-more-btn").hide();
					} else {
						jQuery("#load-more-btn").show();
					};

				}

				//when load more button clicked
				$("#load-more-btn").click(function(e) {
					e.preventDefault();
					counter = counter;
					counter = counter + initShow;
					loadMore(counter);
				});

			<?php } ?>

		});

		
	});

</script>
		
		<?php
		}elseif( $settings['layout_style'] == '2' ){

		}


	}

}