<?php
use \Elementor\Widget_Base;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use \Elementor\Utils;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Border;
use \Elementor\Repeater;
/**
 *
 * Program Widget . 
 *
 */
class Kitar_Program extends Widget_Base {

	public function get_name() {
		return 'kitarprogram';
	}
	public function get_title() {
		return __( 'Program', 'kitar' ); 
	}
	public function get_icon() {
		return 'th-icon';
    }
	public function get_categories() {
		return [ 'kitar' ];
	}

	protected function register_controls() {

		$this->start_controls_section(
			'project_section',
			[
				'label' 	=> __( 'Program', 'kitar' ),
				'tab' 		=> Controls_Manager::TAB_CONTENT,
			]
        );

		kitar_select_field( $this, 'layout_style', 'Layout Style', ['Style One'] );    

		$repeater = new Repeater();

		kitar_media_fields($repeater, 'icon', 'Choose Icon');
		kitar_general_fields($repeater, 'title', 'Title', 'TEXTAREA2', 'Toddler');
		kitar_general_fields($repeater, 'subtitle', 'Subitle', 'TEXTAREA2', '(1.5 - 3 Years)');
		kitar_general_fields($repeater, 'desc', 'Description', 'TEXTAREA', ''); 
		kitar_url_fields($repeater, 'button_url', 'Button URL'); 
		$repeater->add_control(
			'color',
			[
				'label' => esc_html__( 'Color 1', 'kitar' ),
				'type' => \Elementor\Controls_Manager::COLOR,
			]
		);
		$repeater->add_control(
			'color2',
			[
				'label' => esc_html__( 'Color 2', 'kitar' ),
				'type' => \Elementor\Controls_Manager::COLOR,
			]
		);
		$repeater->add_control(
			'color3',
			[
				'label' => esc_html__( 'Color 3', 'kitar' ),
				'type' => \Elementor\Controls_Manager::COLOR,
			]
		);
		
		$this->add_control(
			'program',
			[
				'label' 		=> __( 'Program', 'kitar' ),
				'type' 			=> Controls_Manager::REPEATER,
				'fields' 		=> $repeater->get_controls(),
				'default' 		=> [
					[
						'title' 	=> __( 'Toddler', 'kitar' ),
					],
				],
				'condition'	=> [
					'layout_style' => ['1']
				]
			]
		);

        $this->end_controls_section();

        //---------------------------------------
			//Style Section Start
		//---------------------------------------

		kitar_common_style_fields( $this, 'sub', 'Subtitle', '{{WRAPPER}} .sub' );
		kitar_common_style_fields( $this, 'title', 'Title', '{{WRAPPER}} .title' );
		kitar_common_style_fields( $this, 'content', 'Content', '{{WRAPPER}} .desc' );

	}

	protected function render() {

	$settings = $this->get_settings_for_display();

		if( $settings['layout_style'] == '1' ){
			echo '<div class="row gy-5 justify-content-center justify-content-lg-between">';
				foreach( $settings['program'] as $data ){
					echo '<div class="col-md-6 col-xl-3 program-feature_wrapp">';
						echo '<div class="program-feature" data-theme-color="'.esc_attr($data['color']).'">';
							if(!empty($data['icon']['url'])){
								echo '<div class="box-img ding-dong">';
									echo kitar_img_tag( array(
										'url'   => esc_url( $data['icon']['url'] ), 
									));
								echo '</div>';
							}
							echo '<div class="program-feature_content" data-theme-color="'.esc_attr($data['color2']).'">';
								echo '<div class="prograp-line" data-theme-color="'.esc_attr($data['color3']).'" data-mask-src="'.KITAR_ASSETS.'img/program_line.png"></div>';
								echo '<div class="program-shape" data-bg-src="'.KITAR_ASSETS.'img/program_shape3.png"></div>';
								if(!empty($data['title'])){
									echo '<h3 class="box-title title">'.wp_kses_post($data['title']).'</h3>';
								}
								if(!empty($data['subtitle'])){
									echo '<span class="program-feature_year sub" data-theme-color="'.esc_attr($data['color3']).'">'.wp_kses_post($data['subtitle']).'</span>';
								}
								if(!empty($data['desc'])){
									echo '<p class="program-feature_text desc">'.wp_kses_post($data['desc']).'</p>';
								}
								if(!empty($data['button_url']['url'])){
									echo '<a href="'.esc_url( $data['button_url']['url'] ).'" class="icon-btn" data-theme-color="'.esc_attr($data['color3']).'"><i class="fa-regular fa-arrow-right"></i></a>';
								}
							echo '</div>';
						echo '</div>';
					echo '</div>';
				}
			echo '</div>';

		}


	}

}