<?php
use \Elementor\Widget_Base;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use \Elementor\Utils;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Border;
use \Elementor\Repeater;
/**
 *
 * Service Widget .
 *
 */
class kitar_Service extends Widget_Base {

	public function get_name() {
		return 'kitarservice';
	}
	public function get_title() {
		return __( 'Services', 'kitar' );
	}
	public function get_icon() {
		return 'th-icon';
    }
	public function get_categories() {
		return [ 'kitar' ];
	}

	protected function register_controls() {

		 $this->start_controls_section(
			'service_section',
			[
				'label'     => __( 'Services', 'kitar' ),
				'tab'       => Controls_Manager::TAB_CONTENT,
			]
        );

		kitar_select_field( $this, 'layout_style', 'Layout Style', [ 'Style One', 'Style Two' ] );

		$repeater = new Repeater();

		kitar_media_fields($repeater, 'choose_image', 'Choose Image');
		kitar_general_fields($repeater, 'number', 'Number', 'TEXTAREA2', '01');
		kitar_general_fields($repeater, 'title', 'Title', 'TEXTAREA2', 'Licensed Child Care');
		kitar_general_fields($repeater, 'description', 'Description', 'TEXTAREA', ''); 
		kitar_general_fields($repeater, 'button_text', 'Button Text', 'TEXT', 'Purchase Ticket');
		kitar_url_fields($repeater, 'button_url', 'Button URL');
		$repeater->add_control(
			'color',
			[
				'label' => esc_html__( 'Color 1', 'kitar' ),
				'type' => \Elementor\Controls_Manager::COLOR,
			]
		);
		$repeater->add_control(
			'color2',
			[
				'label' => esc_html__( 'Color 2', 'kitar' ),
				'type' => \Elementor\Controls_Manager::COLOR,
			]
		);
		
		$this->add_control(
			'service_list',
			[
				'label' 		=> __( 'Service Lists', 'kitar' ),
				'type' 			=> Controls_Manager::REPEATER,
				'fields' 		=> $repeater->get_controls(),
				'default' 		=> [
					[
						'title' 	=> __( 'Licensed Child Care', 'kitar' ),
					],
				],
				'condition'	=> [
					'layout_style' => ['1', '2']
				]
			]
		);


        $this->end_controls_section();

        //---------------------------------------
			//Style Section Start
		//---------------------------------------

		//-------Title Style-------
		kitar_common2_style_fields( $this, 'title', 'Title', '{{WRAPPER}} .title a', ['1', '2', '4'] );
		kitar_common_style_fields( $this, 'num', 'Number', '{{WRAPPER}} .service-box_number', ['1', '2'] );
		//-------Description Style-------
		kitar_common_style_fields( $this, 'desc', 'Description', '{{WRAPPER}} .desc' );

		//------Button Style-------
		kitar_button_style_fields( $this, '16', 'Button Styling', '{{WRAPPER}} .th_btn' );

	}

	protected function render() {

        $settings = $this->get_settings_for_display();

		if( $settings['layout_style'] == '1' ){
			echo '<div class="slider-area">';
				echo '<div class="swiper th-slider serviceSlider3 has-shadow" id="serviceSlider3" data-slider-options=\'{"breakpoints":{"0":{"slidesPerView":1},"576":{"slidesPerView":"1"},"768":{"slidesPerView":"2"},"992":{"slidesPerView":"2"},"1200":{"slidesPerView":"3"}}}\'>';
					echo '<div class="swiper-wrapper">';
						foreach( $settings['service_list'] as $data ){
						echo '<div class="swiper-slide">';
							echo '<div class="service-box">';
								echo '<div class="service-shape" data-bg-color="'.esc_attr($data['color']).'"></div>';
								if(!empty($data['choose_image']['url'])){
									echo '<div class="service-box_img">';
										echo kitar_img_tag( array(
											'url'   => esc_url( $data['choose_image']['url'] ),
										));
									echo '</div>';
								}
								echo '<div class="service-box_content">';
									if(!empty($data['number'])){
										echo '<span class="service-box_number" data-theme-color="'.esc_attr($data['color']).'">'.esc_html($data['number']).'</span>';
									}
									if(!empty($data['title'])){
										echo '<h3 class="box-title title"><a href="'.esc_url( $data['button_url']['url'] ).'">'.esc_html($data['title']).'</a></h3>';
									}
									if(!empty($data['description'])){
										echo '<p class="service-box_text desc">'.esc_html($data['description']).'</p>';
									}
									if(!empty($data['button_text'])){
										echo '<a href="'.esc_url( $data['button_url']['url'] ).'" class="th-btn th_btn" data-theme-color="'.esc_attr($data['color2']).'">'.wp_kses_post($data['button_text']).'</a>';
									}
								echo '</div>';
							echo '</div>';
						echo '</div>';
						}
					echo '</div>';
				echo '</div>';
				echo '<button data-slider-prev="#serviceSlider3" class="slider-arrow slider-prev"><i class="far fa-arrow-left"></i></button>';
				echo '<button data-slider-next="#serviceSlider3" class="slider-arrow slider-next"><i class="far fa-arrow-right"></i></button>';
			echo '</div>';

		}elseif( $settings['layout_style'] == '2' ){
			echo '<div class="row gy-30 gx-30">';
				foreach( $settings['service_list'] as $data ){
					echo '<div class="col-xl-4 col-md-6">';
						echo '<div class="service-box">';
							echo '<div class="service-shape" data-bg-color="'.esc_attr($data['color']).'"></div>';
							if(!empty($data['choose_image']['url'])){
								echo '<div class="service-box_img">';
									echo kitar_img_tag( array(
										'url'   => esc_url( $data['choose_image']['url'] ),
									));
								echo '</div>';
							}
							echo '<div class="service-box_content">';
								if(!empty($data['number'])){
									echo '<span class="service-box_number" data-theme-color="'.esc_attr($data['color']).'">'.esc_html($data['number']).'</span>';
								}
								if(!empty($data['title'])){
									echo '<h3 class="box-title title"><a href="'.esc_url( $data['button_url']['url'] ).'">'.esc_html($data['title']).'</a></h3>';
								}
								if(!empty($data['description'])){
									echo '<p class="service-box_text desc">'.esc_html($data['description']).'</p>';
								}
								if(!empty($data['button_text'])){
									echo '<a href="'.esc_url( $data['button_url']['url'] ).'" class="th-btn th_btn" data-theme-color="'.esc_attr($data['color2']).'">'.wp_kses_post($data['button_text']).'</a>';
								}
							echo '</div>';
						echo '</div>';
					echo '</div>';
				}
			echo '</div>';

		}


	}

}