<?php
use \Elementor\Widget_Base;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use \Elementor\Utils;
use \Elementor\Repeater;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Group_Control_Box_Shadow;
/**
 *
 * Testimonial Slider Widget .
 *
 */
class kitar_Testimonial extends Widget_Base{

	public function get_name() {
		return 'kitartestimonialslider';
	}
	public function get_title() {
		return __( 'Testimonials', 'kitar' );
	}
	public function get_icon() {
		return 'th-icon';
    }
	public function get_categories() {
		return [ 'kitar' ];
	}

	protected function register_controls() {

		$this->start_controls_section(
			'testimonial_slider_section',
			[
				'label' 	=> __( 'Testimonial Slider', 'kitar' ), 
				'tab' 		=> Controls_Manager::TAB_CONTENT,
			]
		);

		kitar_select_field( $this, 'layout_style', 'Layout Style', [ 'Style One', 'Style Two', 'Style Three' ] );

		kitar_media_fields( $this, 'image', 'Image', ['1', '2'] );
		kitar_media_fields( $this, 'line', 'Line Image', ['1'] );
		
		kitar_general_fields( $this, 'subtitle', 'Subtitle', 'TEXTAREA2', 'Get Consultation', ['1', '2'] );
		kitar_general_fields( $this, 'title', 'Title', 'TEXTAREA2', 'Get A Free Consultation Contact Us', ['1', '2'] );

		kitar_media_fields( $this, 'quote', 'Quote Image', ['1', '2', '3'] );
		kitar_media_fields( $this, 'shape', 'Shape Image', ['2'] );

		$repeater = new Repeater();

		kitar_media_fields( $repeater, 'client_image', 'Client Image' );
		kitar_general_fields( $repeater, 'client_name', 'Client Name', 'TEXT', 'Alex Michel' );
		kitar_general_fields( $repeater, 'client_desig', 'Client Designation', 'TEXT', 'Ui/Ux Designer' );
		kitar_general_fields( $repeater, 'client_feedback', 'Client Feedback', 'TEXTAREA', 'Our knowledgeable technicians are happy to provide tips' );

		kitar_select_field( $repeater, 'client_rating', 'Client Rating', [ 'One Star', 'Two Star', 'Three Star', 'Four Star', 'Five Star' ] );

		$this->add_control(
			'slides',
			[
				'label' 		=> __( 'Slides', 'kitar' ),
				'type' 			=> Controls_Manager::REPEATER,
				'fields' 		=> $repeater->get_controls(),
				'default' 		=> [
					[
						'client_image'	=> Utils::get_placeholder_image_src(),
					],
				],
				'title_field' 	=> '{{{ client_name }}}',
				'condition'		=> [ 
					'layout_style' => [ '1', '2', '3'],
				],
			]
		);

		$this->end_controls_section();

        //---------------------------------------
			//Style Section Start
		//---------------------------------------
		
		//-------Subtitle Style-------
		kitar_common_style_fields( $this, 'subtitle', 'Subtitle', '{{WRAPPER}} .sub', ['1', '2'] );
		//-------Title Style------- 
		kitar_common_style_fields( $this, 'title', 'Title', '{{WRAPPER}} .title', ['1', '2'] );
		//-------Name Style-------
		kitar_common_style_fields( $this, 'name', 'Name', '{{WRAPPER}} .name', ['1', '2'] );
		//-------Designation Style-------
		kitar_common_style_fields( $this, 'designation', 'Designation', '{{WRAPPER}} .desig', ['1', '2'] );
		//-------Feedback Style-------
		kitar_common_style_fields( $this, 'feedback', 'Feedback', '{{WRAPPER}} .text' );
		
	}

	protected function render() {

		$settings = $this->get_settings_for_display();

		if( $settings['layout_style'] == '1' ){
			echo '<div class="testi-sec">';
				echo '<div class="container">';
					echo '<div class="row align-items-center">';
						echo '<div class="col-xl-6">';
							echo '<div class="testi-wrapper">';
								if(!empty($settings['image']['url'])){
									echo '<div class="testi-image">';
										echo kitar_img_tag( array(
											'url'	=> esc_url( $settings['image']['url'] ),
										) );
									echo '</div>';
								}
								if(!empty($settings['line']['url'])){
									echo '<div class="testi-shape">';
										echo kitar_img_tag( array(
											'url'	=> esc_url( $settings['line']['url'] ),
										) );
									echo '</div>';
								}
								echo '<div class="team-thumb" data-slider-tab="#testiSlide1">';
									foreach( $settings['slides'] as $key => $data ){
										$active = ($key==0) ? 'active':'';
										echo '<div class="tab-btn '.esc_attr($active).'"></div>';
									}
								echo '</div>';
							echo '</div>';
						echo '</div>';
						echo '<div class="col-xl-6">';
							echo '<div class="testi-area">';
								echo '<div class="title-area mb-40">';
									if($settings['subtitle']){
										echo '<span class="sub-title sub">'.wp_kses_post($settings['subtitle']).'</span>';
									}
									if($settings['title']){
										echo '<h2 class="sec-title title">'.wp_kses_post($settings['title']).'</h2>';
									}
								echo '</div>';
								echo '<div class="swiper th-slider team-slider" id="testiSlide1" data-slider-options=\'{"effect":"slide","loop":false,"spaceBetween":10}\'>';
									echo '<div class="swiper-wrapper">';
									foreach( $settings['slides'] as $data ){
										echo '<div class="swiper-slide">';
											echo '<div class="testi-card">';
												echo '<div class="testi-card_wrapper">';
													if(!empty($settings['quote']['url'])){
														echo '<div class="testi-card-quote">';
															echo kitar_img_tag( array(
																'url'	=> esc_url( $settings['quote']['url'] ),
															) );
														echo '</div>';
													}
													echo '<div class="testi-card_review">';
														if( $data['client_rating'] == '1' ){
															echo '<i class="fa-solid fa-star"></i>';
															echo '<i class="fa-regular fa-star"></i>';
															echo '<i class="fa-regular fa-star"></i>';
															echo '<i class="fa-regular fa-star"></i>';
															echo '<i class="fa-regular fa-star"></i>';
														}elseif( $data['client_rating'] == '2' ){
															echo '<i class="fa-solid fa-star"></i>';
															echo '<i class="fa-solid fa-star"></i>';
															echo '<i class="fa-regular fa-star"></i>';
															echo '<i class="fa-regular fa-star"></i>';
															echo '<i class="fa-regular fa-star"></i>';
														}elseif( $data['client_rating'] == '3' ){
															echo '<i class="fa-solid fa-star"></i>';
															echo '<i class="fa-solid fa-star"></i>';
															echo '<i class="fa-solid fa-star"></i>';
															echo '<i class="fa-regular fa-star"></i>';
															echo '<i class="fa-regular fa-star"></i>';
														}elseif( $data['client_rating'] == '4' ){
															echo '<i class="fa-solid fa-star"></i>';
															echo '<i class="fa-solid fa-star"></i>';
															echo '<i class="fa-solid fa-star"></i>';
															echo '<i class="fa-solid fa-star"></i>';
															echo '<i class="fa-regular fa-star"></i>';
														}else{
															echo '<i class="fa-solid fa-star"></i>';
															echo '<i class="fa-solid fa-star"></i>';
															echo '<i class="fa-solid fa-star"></i>';
															echo '<i class="fa-solid fa-star"></i>';
															echo '<i class="fa-solid fa-star"></i>';
														}
													echo '</div>';
												echo '</div>';
												if(!empty($data['client_feedback'])){
													echo '<p class="testi-card_text text">'.wp_kses_post( $data['client_feedback'] ).'</p>';
												}
												echo '<div class="testi-card_profile">';
													if(!empty($data['client_image']['url'])){
														echo '<div class="testi-card_avater">';
															echo kitar_img_tag( array(
																'url'	=> esc_url( $data['client_image']['url'] ),
															) );
														echo '</div>';
													}
													echo '<div class="testi-card_content">';
														if(!empty($data['client_name'])){
															echo '<h3 class="testi-card_name box-title name">'.wp_kses_post( $data['client_name'] ).'</h3>';
														}
														if(!empty($data['client_desig'])){
															echo '<span class="testi-card_desig desig">'.wp_kses_post( $data['client_desig'] ).'</span>';
														}
													echo '</div>';
												echo '</div>';
											echo '</div>';
										echo '</div>';
									}
									echo '</div>';
								echo '</div>';
							echo '</div>';
						echo '</div>';
					echo '</div>';
				echo '</div>';
			echo '</div>';

		}elseif( $settings['layout_style'] == '2' ){
			echo '<div class="row">';
				echo '<div class="col-xl-7">';
					if(!empty($settings['image']['url'])){
						echo '<div class="testi-image2" data-mask-src="'.KITAR_ASSETS.'img/shape/testi-img-shape.png">';
							echo kitar_img_tag( array(
								'url'	=> esc_url( $settings['image']['url'] ),
							) );
						echo '</div>';
					}
				echo '</div>';
				echo '<div class="col-xl-5">';
					echo '<div class="title-area ms-xl-4 mt-40">';
						if($settings['subtitle']){
							echo '<span class="sub-title sub">'.wp_kses_post($settings['subtitle']).'</span>';
						}
						if($settings['title']){
							echo '<h2 class="sec-title title">'.wp_kses_post($settings['title']).'</h2>';
						}
					echo '</div>';
					echo '<div class="testi-slider">';
						echo '<div class="swiper th-slider team-slider" id="testiSlide1" data-slider-options=\'{"effect":"fade","loop":false,"spaceBetween":10}\'>';
							echo '<div class="swiper-wrapper">';
								foreach( $settings['slides'] as $data ){
									echo '<div class="swiper-slide">';
										echo '<div class="testi-box">';
											echo '<div class="testi-box_profile">';
												if(!empty($data['client_feedback'])){
													echo '<p class="testi-box_text text">'.wp_kses_post( $data['client_feedback'] ).'</p>';
												}
												if(!empty($data['client_image']['url'])){
													echo '<div class="testi-box_img">';
														echo kitar_img_tag( array(
															'url'	=> esc_url( $data['client_image']['url'] ),
															'class' => 'img1',
														) );
													echo '</div>';
												}
											echo '</div>';
											echo '<div class="testi-box_wrapper">';
												echo '<div class="testi-box_review">';
													if( $data['client_rating'] == '1' ){
														echo '<i class="fa-solid fa-star"></i>';
														echo '<i class="fa-regular fa-star"></i>';
														echo '<i class="fa-regular fa-star"></i>';
														echo '<i class="fa-regular fa-star"></i>';
														echo '<i class="fa-regular fa-star"></i>';
													}elseif( $data['client_rating'] == '2' ){
														echo '<i class="fa-solid fa-star"></i>';
														echo '<i class="fa-solid fa-star"></i>';
														echo '<i class="fa-regular fa-star"></i>';
														echo '<i class="fa-regular fa-star"></i>';
														echo '<i class="fa-regular fa-star"></i>';
													}elseif( $data['client_rating'] == '3' ){
														echo '<i class="fa-solid fa-star"></i>';
														echo '<i class="fa-solid fa-star"></i>';
														echo '<i class="fa-solid fa-star"></i>';
														echo '<i class="fa-regular fa-star"></i>';
														echo '<i class="fa-regular fa-star"></i>';
													}elseif( $data['client_rating'] == '4' ){
														echo '<i class="fa-solid fa-star"></i>';
														echo '<i class="fa-solid fa-star"></i>';
														echo '<i class="fa-solid fa-star"></i>';
														echo '<i class="fa-solid fa-star"></i>';
														echo '<i class="fa-regular fa-star"></i>';
													}else{
														echo '<i class="fa-solid fa-star"></i>';
														echo '<i class="fa-solid fa-star"></i>';
														echo '<i class="fa-solid fa-star"></i>';
														echo '<i class="fa-solid fa-star"></i>';
														echo '<i class="fa-solid fa-star"></i>';
													}
												echo '</div>';
												if(!empty($data['client_name'])){
													echo '<h3 class="box-title name">'.wp_kses_post( $data['client_name'] ).'</h3>';
												}
												if(!empty($data['client_desig'])){
													echo '<span class="testi-card_desig desig">'.wp_kses_post( $data['client_desig'] ).'</span>';
												}
											echo '</div>';
										echo '</div>';
									echo '</div>';
								}
							echo '</div>';
						echo '</div>';
						if(!empty($settings['shape']['url'])){
						echo '<div class="testi-frame">';
							echo kitar_img_tag( array(
								'url'	=> esc_url( $settings['shape']['url'] ),
							) );
						echo '</div>';
						}
						if(!empty($settings['quote']['url'])){
						echo '<div class="testi-quote">';
							echo kitar_img_tag( array(
								'url'	=> esc_url( $settings['quote']['url'] ),
							) );
						echo '</div>';
						}
					echo '</div>';
				echo '</div>';
			echo '</div>';
			
		}elseif( $settings['layout_style'] == '3' ){
			echo '<div class="swiper th-slider testi-slider3" id="testiSlide3" data-slider-options=\'{"effect":"slide","loop":false,"spaceBetween":10}\'>';
				echo '<div class="swiper-wrapper">';
				foreach( $settings['slides'] as $data ){
					echo '<div class="swiper-slide">';
						echo '<div class="testi-card">';
							echo '<div class="testi-card_wrapper">';
								if(!empty($settings['quote']['url'])){
									echo '<div class="testi-card-quote">';
										echo kitar_img_tag( array(
											'url'	=> esc_url( $settings['quote']['url'] ),
										) );
									echo '</div>';
								}
								echo '<div class="testi-card_review">';
									if( $data['client_rating'] == '1' ){
										echo '<i class="fa-solid fa-star"></i>';
										echo '<i class="fa-regular fa-star"></i>';
										echo '<i class="fa-regular fa-star"></i>';
										echo '<i class="fa-regular fa-star"></i>';
										echo '<i class="fa-regular fa-star"></i>';
									}elseif( $data['client_rating'] == '2' ){
										echo '<i class="fa-solid fa-star"></i>';
										echo '<i class="fa-solid fa-star"></i>';
										echo '<i class="fa-regular fa-star"></i>';
										echo '<i class="fa-regular fa-star"></i>';
										echo '<i class="fa-regular fa-star"></i>';
									}elseif( $data['client_rating'] == '3' ){
										echo '<i class="fa-solid fa-star"></i>';
										echo '<i class="fa-solid fa-star"></i>';
										echo '<i class="fa-solid fa-star"></i>';
										echo '<i class="fa-regular fa-star"></i>';
										echo '<i class="fa-regular fa-star"></i>';
									}elseif( $data['client_rating'] == '4' ){
										echo '<i class="fa-solid fa-star"></i>';
										echo '<i class="fa-solid fa-star"></i>';
										echo '<i class="fa-solid fa-star"></i>';
										echo '<i class="fa-solid fa-star"></i>';
										echo '<i class="fa-regular fa-star"></i>';
									}else{
										echo '<i class="fa-solid fa-star"></i>';
										echo '<i class="fa-solid fa-star"></i>';
										echo '<i class="fa-solid fa-star"></i>';
										echo '<i class="fa-solid fa-star"></i>';
										echo '<i class="fa-solid fa-star"></i>';
									}
								echo '</div>';
							echo '</div>';
							if(!empty($data['client_feedback'])){
								echo '<p class="testi-card_text text">'.wp_kses_post( $data['client_feedback'] ).'</p>';
							}
							echo '<div class="testi-card_profile">';
								if(!empty($data['client_image']['url'])){
									echo '<div class="testi-card_avater">';
										echo kitar_img_tag( array(
											'url'	=> esc_url( $data['client_image']['url'] ),
										) );
									echo '</div>';
								}
								echo '<div class="testi-card_content">';
									if(!empty($data['client_name'])){
										echo '<h3 class="testi-card_name name">'.wp_kses_post( $data['client_name'] ).'</h3>';
									}
									if(!empty($data['client_desig'])){
										echo '<span class="testi-card_desig desig">'.wp_kses_post( $data['client_desig'] ).'</span>';
									}
								echo '</div>';
							echo '</div>';
						echo '</div>';
					echo '</div>';
				}
				echo '</div>';
				echo '<div class="icon-box">';
					echo '<button data-slider-prev="#testiSlide3" class="slider-arrow style2 default"><i class="far fa-arrow-left"></i></button>';
					echo '<button data-slider-next="#testiSlide3" class="slider-arrow style2 default"><i class="far fa-arrow-right"></i></button>';
				echo '</div>';
			echo '</div>';

		}


	}

}